import BaseLayout from "@/components/BaseLayout";
import type { Metadata } from "next";
import { AppRouterCacheProvider } from "@mui/material-nextjs/v14-appRouter";

export const dynamic = "force-dynamic";

export const metadata: Metadata = {
  title: process.env.RODOLF_APP_TITLE ?? "Rodolf",
};

// See https://mui.com/material-ui/guides/nextjs/
export default function RootLayout({
  children,
}: {
  children: React.ReactNode;
}) {
  const API_ENDPOINT = process.env.RODOLF_API_URL;
  const APP_TITLE = process.env.RODOLF_APP_TITLE;
  const APP_LOGO = process.env.RODOLF_APP_LOGO_B64;

  if (!API_ENDPOINT) {
    console.error("No api endpoint configured");
  }

  return (
    <html lang="en">
      <body style={{ margin: 0 }}>
        <AppRouterCacheProvider>
          <BaseLayout
            endpoint={API_ENDPOINT}
            title={APP_TITLE ?? "Rodolf"}
            logoBase64={APP_LOGO}
          >
            {children}
          </BaseLayout>
        </AppRouterCacheProvider>
      </body>
    </html>
  );
}
